==> chaosmesh-model-5.4.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosActionFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface IoChaosActionFluent<A extends io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildAtime instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.Timespec getAtime();
    public io.fabric8.chaosmesh.v1alpha1.Timespec buildAtime();
    public A withAtime(io.fabric8.chaosmesh.v1alpha1.Timespec atime);
    public java.lang.Boolean hasAtime();
    public A withNewAtime(java.lang.Long nsec,java.lang.Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> withNewAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> withNewAtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editOrNewAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editOrNewAtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public java.lang.Long getBlocks();
    public A withBlocks(java.lang.Long blocks);
    public java.lang.Boolean hasBlocks();
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildCtime instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.Timespec getCtime();
    public io.fabric8.chaosmesh.v1alpha1.Timespec buildCtime();
    public A withCtime(io.fabric8.chaosmesh.v1alpha1.Timespec ctime);
    public java.lang.Boolean hasCtime();
    public A withNewCtime(java.lang.Long nsec,java.lang.Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> withNewCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> withNewCtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editOrNewCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editOrNewCtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public A addToFaults(int index,io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public A setToFaults(int index,io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public A addToFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
    public A addAllToFaults(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.IoFault> items);
    public A removeFromFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
    public A removeAllFromFaults(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.IoFault> items);
    public A removeMatchingFromFaults(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildFaults instead.
     * @return The buildable object.
     */
        public java.util.List<io.fabric8.chaosmesh.v1alpha1.IoFault> getFaults();
    public java.util.List<io.fabric8.chaosmesh.v1alpha1.IoFault> buildFaults();
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildFault(int index);
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildFirstFault();
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildLastFault();
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildMatchingFault(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    public java.lang.Boolean hasMatchingFault(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    public A withFaults(java.util.List<io.fabric8.chaosmesh.v1alpha1.IoFault> faults);
    public A withFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... faults);
    public java.lang.Boolean hasFaults();
    public A addNewFault(java.lang.Integer errno,java.lang.Integer weight);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> addNewFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> addNewFaultLike(io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> setNewFaultLike(int index,io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editFault(int index);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editFirstFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editLastFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editMatchingFault(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    public java.lang.Long getGid();
    public A withGid(java.lang.Long gid);
    public java.lang.Boolean hasGid();
    public java.lang.Long getIno();
    public A withIno(java.lang.Long ino);
    public java.lang.Boolean hasIno();
    public java.lang.String getKind();
    public A withKind(java.lang.String kind);
    public java.lang.Boolean hasKind();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withKind instead.
     */
        public A withNewKind(java.lang.String arg0);
    public java.lang.String getLatency();
    public A withLatency(java.lang.String latency);
    public java.lang.Boolean hasLatency();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withLatency instead.
     */
        public A withNewLatency(java.lang.String arg0);
    public A addToMethods(int index,java.lang.String item);
    public A setToMethods(int index,java.lang.String item);
    public A addToMethods(java.lang.String... items);
    public A addAllToMethods(java.util.Collection<java.lang.String> items);
    public A removeFromMethods(java.lang.String... items);
    public A removeAllFromMethods(java.util.Collection<java.lang.String> items);
    public java.util.List<java.lang.String> getMethods();
    public java.lang.String getMethod(int index);
    public java.lang.String getFirstMethod();
    public java.lang.String getLastMethod();
    public java.lang.String getMatchingMethod(java.util.function.Predicate<java.lang.String> predicate);
    public java.lang.Boolean hasMatchingMethod(java.util.function.Predicate<java.lang.String> predicate);
    public A withMethods(java.util.List<java.lang.String> methods);
    public A withMethods(java.lang.String... methods);
    public java.lang.Boolean hasMethods();
    public A addNewMethod(java.lang.String arg0);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildMtime instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.Timespec getMtime();
    public io.fabric8.chaosmesh.v1alpha1.Timespec buildMtime();
    public A withMtime(io.fabric8.chaosmesh.v1alpha1.Timespec mtime);
    public java.lang.Boolean hasMtime();
    public A withNewMtime(java.lang.Long nsec,java.lang.Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> withNewMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> withNewMtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editOrNewMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editOrNewMtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public java.lang.Long getNlink();
    public A withNlink(java.lang.Long nlink);
    public java.lang.Boolean hasNlink();
    public java.lang.String getPath();
    public A withPath(java.lang.String path);
    public java.lang.Boolean hasPath();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withPath instead.
     */
        public A withNewPath(java.lang.String arg0);
    public java.lang.Integer getPercent();
    public A withPercent(java.lang.Integer percent);
    public java.lang.Boolean hasPercent();
    public java.lang.Integer getPerm();
    public A withPerm(java.lang.Integer perm);
    public java.lang.Boolean hasPerm();
    public java.lang.Long getRdev();
    public A withRdev(java.lang.Long rdev);
    public java.lang.Boolean hasRdev();
    public java.lang.Long getSize();
    public A withSize(java.lang.Long size);
    public java.lang.Boolean hasSize();
    public java.lang.String getSource();
    public A withSource(java.lang.String source);
    public java.lang.Boolean hasSource();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withSource instead.
     */
        public A withNewSource(java.lang.String arg0);
    public java.lang.String getType();
    public A withType(java.lang.String type);
    public java.lang.Boolean hasType();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withType instead.
     */
        public A withNewType(java.lang.String arg0);
    public java.lang.Long getUid();
    public A withUid(java.lang.Long uid);
    public java.lang.Boolean hasUid();
    public interface AtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<N>> {

            public N and();
            public N endAtime();    }


    public interface CtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<N>> {

            public N and();
            public N endCtime();    }


    public interface FaultsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.IoFaultFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<N>> {

            public N and();
            public N endFault();    }


    public interface MtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<N>> {

            public N and();
            public N endMtime();    }


}

==> chaosmesh-model-5.7.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosActionFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface IoChaosActionFluent<A extends io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildAtime instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.Timespec getAtime();
    public io.fabric8.chaosmesh.v1alpha1.Timespec buildAtime();
    public A withAtime(io.fabric8.chaosmesh.v1alpha1.Timespec atime);
    public java.lang.Boolean hasAtime();
    public A withNewAtime(java.lang.Long nsec,java.lang.Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> withNewAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> withNewAtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editOrNewAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editOrNewAtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public java.lang.Long getBlocks();
    public A withBlocks(java.lang.Long blocks);
    public java.lang.Boolean hasBlocks();
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildCtime instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.Timespec getCtime();
    public io.fabric8.chaosmesh.v1alpha1.Timespec buildCtime();
    public A withCtime(io.fabric8.chaosmesh.v1alpha1.Timespec ctime);
    public java.lang.Boolean hasCtime();
    public A withNewCtime(java.lang.Long nsec,java.lang.Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> withNewCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> withNewCtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editOrNewCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editOrNewCtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public A addToFaults(int index,io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public A setToFaults(int index,io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public A addToFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
    public A addAllToFaults(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.IoFault> items);
    public A removeFromFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
    public A removeAllFromFaults(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.IoFault> items);
    public A removeMatchingFromFaults(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildFaults instead.
     * @return The buildable object.
     */
        public java.util.List<io.fabric8.chaosmesh.v1alpha1.IoFault> getFaults();
    public java.util.List<io.fabric8.chaosmesh.v1alpha1.IoFault> buildFaults();
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildFault(int index);
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildFirstFault();
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildLastFault();
    public io.fabric8.chaosmesh.v1alpha1.IoFault buildMatchingFault(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    public java.lang.Boolean hasMatchingFault(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    public A withFaults(java.util.List<io.fabric8.chaosmesh.v1alpha1.IoFault> faults);
    public A withFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... faults);
    public java.lang.Boolean hasFaults();
    public A addNewFault(java.lang.Integer errno,java.lang.Integer weight);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> addNewFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> addNewFaultLike(io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> setNewFaultLike(int index,io.fabric8.chaosmesh.v1alpha1.IoFault item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editFault(int index);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editFirstFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editLastFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editMatchingFault(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.IoFaultBuilder> predicate);
    public java.lang.Long getGid();
    public A withGid(java.lang.Long gid);
    public java.lang.Boolean hasGid();
    public java.lang.Long getIno();
    public A withIno(java.lang.Long ino);
    public java.lang.Boolean hasIno();
    public java.lang.String getKind();
    public A withKind(java.lang.String kind);
    public java.lang.Boolean hasKind();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withKind instead.
     */
        public A withNewKind(java.lang.String arg0);
    public java.lang.String getLatency();
    public A withLatency(java.lang.String latency);
    public java.lang.Boolean hasLatency();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withLatency instead.
     */
        public A withNewLatency(java.lang.String arg0);
    public A addToMethods(int index,java.lang.String item);
    public A setToMethods(int index,java.lang.String item);
    public A addToMethods(java.lang.String... items);
    public A addAllToMethods(java.util.Collection<java.lang.String> items);
    public A removeFromMethods(java.lang.String... items);
    public A removeAllFromMethods(java.util.Collection<java.lang.String> items);
    public java.util.List<java.lang.String> getMethods();
    public java.lang.String getMethod(int index);
    public java.lang.String getFirstMethod();
    public java.lang.String getLastMethod();
    public java.lang.String getMatchingMethod(java.util.function.Predicate<java.lang.String> predicate);
    public java.lang.Boolean hasMatchingMethod(java.util.function.Predicate<java.lang.String> predicate);
    public A withMethods(java.util.List<java.lang.String> methods);
    public A withMethods(java.lang.String... methods);
    public java.lang.Boolean hasMethods();
    public A addNewMethod(java.lang.String arg0);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildMistake instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.MistakeSpec getMistake();
    public io.fabric8.chaosmesh.v1alpha1.MistakeSpec buildMistake();
    public A withMistake(io.fabric8.chaosmesh.v1alpha1.MistakeSpec mistake);
    public java.lang.Boolean hasMistake();
    public A withNewMistake(java.lang.String filling,java.lang.Long maxLength,java.lang.Long maxOccurrences);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MistakeNested<A> withNewMistake();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MistakeNested<A> withNewMistakeLike(io.fabric8.chaosmesh.v1alpha1.MistakeSpec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MistakeNested<A> editMistake();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MistakeNested<A> editOrNewMistake();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MistakeNested<A> editOrNewMistakeLike(io.fabric8.chaosmesh.v1alpha1.MistakeSpec item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildMtime instead.
     * @return The buildable object.
     */
        public io.fabric8.chaosmesh.v1alpha1.Timespec getMtime();
    public io.fabric8.chaosmesh.v1alpha1.Timespec buildMtime();
    public A withMtime(io.fabric8.chaosmesh.v1alpha1.Timespec mtime);
    public java.lang.Boolean hasMtime();
    public A withNewMtime(java.lang.Long nsec,java.lang.Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> withNewMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> withNewMtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editOrNewMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editOrNewMtimeLike(io.fabric8.chaosmesh.v1alpha1.Timespec item);
    public java.lang.Long getNlink();
    public A withNlink(java.lang.Long nlink);
    public java.lang.Boolean hasNlink();
    public java.lang.String getPath();
    public A withPath(java.lang.String path);
    public java.lang.Boolean hasPath();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withPath instead.
     */
        public A withNewPath(java.lang.String arg0);
    public java.lang.Integer getPercent();
    public A withPercent(java.lang.Integer percent);
    public java.lang.Boolean hasPercent();
    public java.lang.Integer getPerm();
    public A withPerm(java.lang.Integer perm);
    public java.lang.Boolean hasPerm();
    public java.lang.Long getRdev();
    public A withRdev(java.lang.Long rdev);
    public java.lang.Boolean hasRdev();
    public java.lang.Long getSize();
    public A withSize(java.lang.Long size);
    public java.lang.Boolean hasSize();
    public java.lang.String getSource();
    public A withSource(java.lang.String source);
    public java.lang.Boolean hasSource();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withSource instead.
     */
        public A withNewSource(java.lang.String arg0);
    public java.lang.String getType();
    public A withType(java.lang.String type);
    public java.lang.Boolean hasType();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withType instead.
     */
        public A withNewType(java.lang.String arg0);
    public java.lang.Long getUid();
    public A withUid(java.lang.Long uid);
    public java.lang.Boolean hasUid();
    public interface AtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<N>> {

            public N and();
            public N endAtime();    }


    public interface CtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<N>> {

            public N and();
            public N endCtime();    }


    public interface FaultsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.IoFaultFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<N>> {

            public N and();
            public N endFault();    }


    public interface MistakeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.MistakeSpecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MistakeNested<N>> {

            public N and();
            public N endMistake();    }


    public interface MtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.chaosmesh.v1alpha1.TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<N>> {

            public N and();
            public N endMtime();    }


}
